/*
 * A filesystem resource.
 *
 * Copyright (C) 2018, 2019, 2020 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#pragma once

#include <ext2fs/ext2fs.h>

#include <fsserver/filesystem_resource.h>



/* A class providing access to a filesystem via the given interfaces. */

class Fs_filesystem : public FilesystemResource
{
private:
  /* Filesystem details. */

  ext2_filsys _fs;
  const char *_devname;

public:
  explicit Fs_filesystem(Paging *paging, ext2_filsys fs, const char *devname)
  : FilesystemResource(paging), _fs(fs), _devname(devname)
  {
  }

  /* Operation methods. */

  long getuserfs(ipc_varg_sys_uid_t uid,
                 ipc_varg_sys_gid_t gid,
                 ipc_varg_sys_mode_t umask,
                 l4_cap_idx_t *ref);

  long getuserfs(sys_uid_t uid, sys_gid_t gid, sys_mode_t umask,
                 l4_cap_idx_t *ref);
};
